# __Change Log__
>__LAST UPDATE:__ 25.02.2020  
>__STATUS:__ Pre-alpha  
>__VERSION:__ v0.0.3

___

## __Pre-alpha__
### __v0.0.1 (23.02.2022)__
- Project created.
- [Module](./investing_scraper/historical_data.py) class added.

### __v0.0.2 (23.05.2022)__
- New [module](./investing_scraper/instrument_details.py) added.

### __v0.0.3 (23.05.2022)__
- New [module](./investing_scraper/instrument_details.py) fixed.

### __v0.0.4 (30.06.2022)__
- New [module](./investing_scraper/instrument_details.py) fixed.
- New [module](./investing_scraper/historical_data.py) fixed.

### __v0.0.5 (30.06.2022)__
- New [module](./investing_scraper/instrument_details.py) fixed.
- New [module](./investing_scraper/historical_data.py) fixed.

___